Fix typos in debug message and comment in ssl-tls.c
diff --git a/library/ssl_tls.c b/library/ssl_tls.c
index c123c7a..7386fdd 100644
--- a/library/ssl_tls.c
+++ b/library/ssl_tls.c
@@ -4331,7 +4331,7 @@
 
                     if( ret != 0 )
                     {
-                        MBEDTLS_SSL_DEBUG_RET( 1, ( "mbedtls_ssl_read_record_layer" ), ret );
+                        MBEDTLS_SSL_DEBUG_RET( 1, ( "ssl_get_next_record" ), ret );
                         return( ret );
                     }
                 }
@@ -7725,7 +7725,7 @@
 
     /*
      * In all other cases, the rest of the message can be dropped.
      * As in ssl_read_record_layer, this needs to be adapted if
      * we implement support for multiple alerts in single records.
      */
@@ -7725,7 +7725,7 @@
     /*
      * In all other cases, the rest of the message can be dropped.
-     * As in ssl_read_record_layer, this needs to be adapted if
+     * As in ssl_get_next_record, this needs to be adapted if
      * we implement support for multiple alerts in single records.
      */